@@ -91,6 +91,8 @@ class Avto(models.Model):
                                 verbose_name="current location")
     posted_by = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE,
                                   default=22)
+    STATUS = (("AVAILABLE", "Available"), ("BOOKED", "Booked"), ("SOLD", "Sold"))
+    status = models.CharField(max_length=16, blank=True, verbose_name='Status of ad', choices=STATUS, default='available')
 
     def get_fields(self):
         return [(field.verbose_name, field.value_from_object(self)) for field in self.__class__._meta.fields]
